export namespace Gitlab {
  /* 错误 */
  export interface Error {
    /**
     * 错误消息
     */
    message: string
  }
  /* 用户 */
  export interface User {
    /**
     * 用户ID
     */
    id: number
    /**
     * 用户名
     */
    username: string
    /**
     * 用户全名
     */
    name: string
    /**
     * 用户状态
     */
    state: string
    /**
     * 用户头像URL
     */
    avatar_url: string
    /**
     * 用户网页URL
     */
    web_url: string
  }

  /* 项目详情 */
  export interface ProjDetail {
    /**
     * 项目ID
     */
    id: number
    /**
     * 项目描述
     */
    description: string
    /**
     * 项目名称
     */
    name: string
    /**
     * 带命名空间的项目路径
     */
    path_with_namespace: string
    /**
     * 项目网页URL
     */
    web_url: string
    /**
     * 项目头像URL（可选）
     */
    avatar_url?: any
    /**
     * 消息（可选）
     */
    message?: string
  }

  /* 管道详情 */
  export interface PipelineDetail {
    /**
     * 管道ID
     */
    id: number
    /**
     * 项目ID
     */
    project_id: number
    /**
     * 分支名
     */
    ref: string
    /**
     * 状态
     */
    status: string
    /**
     * 管道网页URL
     */
    web_url: string
    /**
     * 用户信息
     */
    user: User
    /**
     * 开始时间
     */
    started_at: string
    /**
     * 完成时间
     */
    finished_at: string
    /**
     * 持续时间
     */
    duration: number
    /**
     * 排队持续时间
     */
    queued_duration: number
    /**
     * 消息（可选）
     */
    message?: string
  }

  /* 管道 */
  export interface Pipeline {
    /**
     * 管道ID
     */
    id: number
    /**
     * 项目ID
     */
    project_id: number
    /**
     * SHA值
     */
    sha: string
    /**
     * 分支名
     */
    ref: string
    /**
     * 状态
     */
    status: string
    /**
     * 来源
     */
    source: string
    /**
     * 创建时间
     */
    created_at: string
    /**
     * 更新时间
     */
    updated_at: string
    /**
     * 管道网页URL
     */
    web_url: string
  }

  /* 任务 */
  export interface Job {
    status: string
    stage: string
  }

  /* 徽章 */
  export interface Badge {
    /**
     * 徽章ID
     */
    id: number
    /**
     * 徽章名称
     */
    name: string
    /**
     * 链接URL
     */
    link_url: string
    /**
     * 图片URL
     */
    image_url: string
    /**
     * 渲染后的链接URL
     */
    rendered_link_url: string
    /**
     * 渲染后的图片URL
     */
    rendered_image_url: string
    /**
     * 类型（项目或组）
     */
    kind: "project" | "group"
  }

  /* 管道事件 */
  export interface PipelineEvent {
    /**
     * 对象属性，包含了构建的详细信息
     */
    object_attributes: {
      /**
       * 管道ID
       */
      id: number
      /**
       * 分支名
       */
      ref: string
      /**
       * 提交的SHA值
       */
      sha: string
      /**
       * 构建状态
       */
      status: string
      /**
       * 构建创建时间
       */
      created_at: string
      /**
       * 构建完成时间
       */
      finished_at: string
      /**
       * 构建持续时间，单位为秒
       */
      duration: number
    }
    /**
     * 用户信息
     */
    user: {
      /**
       * 用户姓名
       */
      name: string
      /**
       * 用户名
       */
      username: string
    }
    /**
     * 项目信息
     */
    project: {
      /**
       * 项目ID
       */
      id: number
      /**
       * 项目的web URL
       */
      web_url: string
      /**
       * 带命名空间的项目路径
       */
      path_with_namespace: string
    }
    /**
     * 提交信息
     */
    commit: {
      /**
       * 提交的ID
       */
      id: string
      /**
       * 提交的标题
       */
      title: string
      /**
       * 提交的链接URL
       */
      url: string
    }
    /**
     * 构建信息
     */
    builds: {
      /**
       * 构建的ID
       */
      id: number
      /**
       * 构建的步骤
       */
      stage: string
      /**
       * 构建的状态
       */
      status: string
      /**
       * 构建的结束时间
       * @example 2024-07-29 15:49:21 +0800
       */
      finished_at: string | null
    }[]
  }

  /* 合并请求 */
  export interface MergeRequest {
    /**
     * 合并请求的标题
     */
    title: string
    /**
     * 目标分支
     */
    target_branch: string
    /**
     * 源分支
     */
    source_branch: string
    /**
     * 作者信息
     */
    author: {
      /**
       * 用户名
       */
      username: string
      /**
       * 用户姓名
       */
      name: string
    }
    /**
     * 提交的SHA值
     */
    sha: string
    /**
     * 合并提交的SHA值
     */
    merge_commit_sha: string
    /**
     * 引用信息
     */
    references: {
      /**
       * 完整引用
       */
      full: string
    }
    /**
     * 合并请求的web URL
     */
    web_url: string
  }
}
